
//------------------------------------------------------------//
//                                                            //
//   Class for storage of global goal data                    //
//                                                            //
//------------------------------------------------------------//

class GoalData
{
	_cargo_list = null; // index = 0, 1, 2 for the three cargoes (with lowest cargo ID first)
	_min_transported = 0;
	_start_year = 0;

	constructor()
	{
		this._cargo_list = [-1, -1, -1];
		this._min_transported = 0;
		this._start_year = 0;
	}

	// pick cargoes
	function InitalizeGoals();

	function GetEndYear();

	// For save/load
	function SaveToTable();
	static function CreateFromTable(table);
}

function GoalData::InitalizeGoals()
{
	// Pick 3 random cargoes
	local cargo_list = GSCargoList();
	cargo_list.Valuate(GSBase.RandItem);
	cargo_list.KeepTop(3);

	// Sort them by cargo ID
	cargo_list.Sort(GSList.SORT_BY_ITEM, GSList.SORT_ASCENDING);

	// Store the cargo IDs in this._cargo_list
	local i = 0;
	local cargo_list_str = "";
	foreach(cargo, _ in cargo_list)
	{
		this._cargo_list[i] = cargo;

		if(cargo_list_str != "") cargo_list_str += ", ";
		cargo_list_str += GSCargo.GetCargoLabel(cargo);
		i++;
	}

	// save the start year of the game
	this._start_year = GSDate.GetYear(GSDate.GetCurrentDate());

	// log some info about the goals
	Log.Info("Goal cargoes: " + cargo_list_str, Log.LVL_INFO);
	Log.Info("Target value: " + GSController.GetSetting("transport_target"), Log.LVL_INFO);
	Log.Info("By year: " + this.GetEndYear());
}

function GoalData::GetEndYear()
{
	return this._start_year + GSController.GetSetting("play_years");
}

function GoalData::SaveToTable()
{
	return {
		cargo_list = this._cargo_list,
		start_year = this._start_year
	};
}

/*static*/ function GoalData::CreateFromTable(table)
{
	local result = GoalData();
	result._cargo_list = table.cargo_list;
	result._start_year = table.start_year;

	return result;
}
